@@ -1,14 +1,9 @@
 #![allow(deprecated)]
-use crate::{
-    commitment_config::{CommitmentConfig, CommitmentLevel},
-    message::Message,
-    transaction::Transaction,
-    Pubkey,
-};
+use crate::commitment_config::{CommitmentConfig, CommitmentLevel};
 use pyo3::{exceptions::PyValueError, prelude::*, types::PyTuple, PyTypeInfo};
+use solders_primitives::{message::Message, pubkey::Pubkey, transaction::Transaction};
 use solders_traits::{
-    py_from_bytes_general_via_cbor, pybytes_general_via_cbor, to_py_err, CommonMethods,
-    PyBytesCbor, PyFromBytesCbor, RichcmpEqualityOnly,
+    py_from_bytes_general_via_cbor, pybytes_general_via_cbor, to_py_err, RichcmpEqualityOnly,
 };
 extern crate base64;
 use crate::rpc::tmp_config::{
@@ -20,7 +15,7 @@ use serde_with::{serde_as, skip_serializing_none, DisplayFromStr, FromInto};
 use solana_sdk::{
     message::Message as MessageOriginal, transaction::Transaction as TransactionOriginal,
 };
-use solders_macros::{common_methods, richcmp_eq_only, rpc_id_getter};
+use solders_macros::{common_methods, richcmp_eq_only, rpc_id_getter, EnumIntoPy};
 
 use crate::{Signature, SolderHash};
 
@@ -47,7 +42,8 @@ macro_rules! rpc_impl_display {
 macro_rules! request_boilerplate {
     ($name:ident) => {
         rpc_impl_display!($name);
-        impl CommonMethods<'_> for $name {
+        impl solders_traits::CommonMethodsCore for $name {}
+        impl solders_traits::CommonMethods<'_> for $name {
             fn py_to_json(&self) -> String {
                 let wrapped = Body::from(self.clone());
                 serde_json::to_string(&wrapped).unwrap()
@@ -2713,19 +2709,11 @@ zero_param_req_def!(VoteSubscribe);
 
 macro_rules ! pyunion {
     ($name:ident, $($variant:ident),+) => {
-        #[derive(FromPyObject, Clone, Debug, PartialEq, Serialize, Deserialize)]
+        #[derive(FromPyObject, Clone, Debug, PartialEq, Serialize, Deserialize, EnumIntoPy)]
         #[serde(tag = "method", rename_all = "camelCase")]
         pub enum $name {
             $($variant($variant),)+
         }
-
-        impl IntoPy<PyObject> for $name {
-            fn into_py(self, py: Python<'_>) -> PyObject {
-                match self {
-                    $(Self::$variant(x) => x.into_py(py),)+
-                }
-            }
-        }
     }
 }
 
